// Copyright 2018 The Go Authors. All rights reserved.
// Use of this source code is governed by a BSD-style
// license that can be found in the LICENSE file.

// Code generated by protoc-gen-go. DO NOT EDIT.
// source: cmd/protoc-gen-go/testdata/imports/test_import_all.proto

package imports

import (
	fmt "google.golang.org/protobuf/cmd/protoc-gen-go/testdata/imports/fmt"
	test_a_1 "google.golang.org/protobuf/cmd/protoc-gen-go/testdata/imports/test_a_1"
	_ "google.golang.org/protobuf/cmd/protoc-gen-go/testdata/imports/test_a_2"
	test_b_1 "google.golang.org/protobuf/cmd/protoc-gen-go/testdata/imports/test_b_1"
	protoreflect "google.golang.org/protobuf/reflect/protoreflect"
	protoimpl "google.golang.org/protobuf/runtime/protoimpl"
	reflect "reflect"
	sync "sync"
	unsafe "unsafe"
)

type All struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	Am1           *test_a_1.M1           `protobuf:"bytes,1,opt,name=am1,proto3" json:"am1,omitempty"`
	Am2           *test_a_1.M2           `protobuf:"bytes,2,opt,name=am2,proto3" json:"am2,omitempty"`
	Bm1           *test_b_1.M1           `protobuf:"bytes,5,opt,name=bm1,proto3" json:"bm1,omitempty"`
	Bm2           *test_b_1.M2           `protobuf:"bytes,6,opt,name=bm2,proto3" json:"bm2,omitempty"`
	Fmt           *fmt.M                 `protobuf:"bytes,7,opt,name=fmt,proto3" json:"fmt,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *All) Reset() {
	*x = All{}
	mi := &file_cmd_protoc_gen_go_testdata_imports_test_import_all_proto_msgTypes[0]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *All) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*All) ProtoMessage() {}

func (x *All) ProtoReflect() protoreflect.Message {
	mi := &file_cmd_protoc_gen_go_testdata_imports_test_import_all_proto_msgTypes[0]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use All.ProtoReflect.Descriptor instead.
func (*All) Descriptor() ([]byte, []int) {
	return file_cmd_protoc_gen_go_testdata_imports_test_import_all_proto_rawDescGZIP(), []int{0}
}

func (x *All) GetAm1() *test_a_1.M1 {
	if x != nil {
		return x.Am1
	}
	return nil
}

func (x *All) GetAm2() *test_a_1.M2 {
	if x != nil {
		return x.Am2
	}
	return nil
}

func (x *All) GetBm1() *test_b_1.M1 {
	if x != nil {
		return x.Bm1
	}
	return nil
}

func (x *All) GetBm2() *test_b_1.M2 {
	if x != nil {
		return x.Bm2
	}
	return nil
}

func (x *All) GetFmt() *fmt.M {
	if x != nil {
		return x.Fmt
	}
	return nil
}

var File_cmd_protoc_gen_go_testdata_imports_test_import_all_proto protoreflect.FileDescriptor

const file_cmd_protoc_gen_go_testdata_imports_test_import_all_proto_rawDesc = "" +
	"\n" +
	"8cmd/protoc-gen-go/testdata/imports/test_import_all.proto\x12\x04test\x1a.cmd/protoc-gen-go/testdata/imports/fmt/m.proto\x1a4cmd/protoc-gen-go/testdata/imports/test_a_1/m1.proto\x1a4cmd/protoc-gen-go/testdata/imports/test_a_1/m2.proto\x1a4cmd/protoc-gen-go/testdata/imports/test_a_2/m3.proto\x1a4cmd/protoc-gen-go/testdata/imports/test_a_2/m4.proto\x1a4cmd/protoc-gen-go/testdata/imports/test_b_1/m1.proto\x1a4cmd/protoc-gen-go/testdata/imports/test_b_1/m2.proto\"\xa3\x01\n" +
	"\x03All\x12\x1c\n" +
	"\x03am1\x18\x01 \x01(\v2\n" +
	".test.a.M1R\x03am1\x12\x1c\n" +
	"\x03am2\x18\x02 \x01(\v2\n" +
	".test.a.M2R\x03am2\x12\"\n" +
	"\x03bm1\x18\x05 \x01(\v2\x10.test.b.part1.M1R\x03bm1\x12\"\n" +
	"\x03bm2\x18\x06 \x01(\v2\x10.test.b.part2.M2R\x03bm2\x12\x18\n" +
	"\x03fmt\x18\a \x01(\v2\x06.fmt.MR\x03fmtB?Z=google.golang.org/protobuf/cmd/protoc-gen-go/testdata/importsb\x06proto3"

var (
	file_cmd_protoc_gen_go_testdata_imports_test_import_all_proto_rawDescOnce sync.Once
	file_cmd_protoc_gen_go_testdata_imports_test_import_all_proto_rawDescData []byte
)

func file_cmd_protoc_gen_go_testdata_imports_test_import_all_proto_rawDescGZIP() []byte {
	file_cmd_protoc_gen_go_testdata_imports_test_import_all_proto_rawDescOnce.Do(func() {
		file_cmd_protoc_gen_go_testdata_imports_test_import_all_proto_rawDescData = protoimpl.X.CompressGZIP(unsafe.Slice(unsafe.StringData(file_cmd_protoc_gen_go_testdata_imports_test_import_all_proto_rawDesc), len(file_cmd_protoc_gen_go_testdata_imports_test_import_all_proto_rawDesc)))
	})
	return file_cmd_protoc_gen_go_testdata_imports_test_import_all_proto_rawDescData
}

var file_cmd_protoc_gen_go_testdata_imports_test_import_all_proto_msgTypes = make([]protoimpl.MessageInfo, 1)
var file_cmd_protoc_gen_go_testdata_imports_test_import_all_proto_goTypes = []any{
	(*All)(nil),         // 0: test.All
	(*test_a_1.M1)(nil), // 1: test.a.M1
	(*test_a_1.M2)(nil), // 2: test.a.M2
	(*test_b_1.M1)(nil), // 3: test.b.part1.M1
	(*test_b_1.M2)(nil), // 4: test.b.part2.M2
	(*fmt.M)(nil),       // 5: fmt.M
}
var file_cmd_protoc_gen_go_testdata_imports_test_import_all_proto_depIdxs = []int32{
	1, // 0: test.All.am1:type_name -> test.a.M1
	2, // 1: test.All.am2:type_name -> test.a.M2
	3, // 2: test.All.bm1:type_name -> test.b.part1.M1
	4, // 3: test.All.bm2:type_name -> test.b.part2.M2
	5, // 4: test.All.fmt:type_name -> fmt.M
	5, // [5:5] is the sub-list for method output_type
	5, // [5:5] is the sub-list for method input_type
	5, // [5:5] is the sub-list for extension type_name
	5, // [5:5] is the sub-list for extension extendee
	0, // [0:5] is the sub-list for field type_name
}

func init() { file_cmd_protoc_gen_go_testdata_imports_test_import_all_proto_init() }
func file_cmd_protoc_gen_go_testdata_imports_test_import_all_proto_init() {
	if File_cmd_protoc_gen_go_testdata_imports_test_import_all_proto != nil {
		return
	}
	type x struct{}
	out := protoimpl.TypeBuilder{
		File: protoimpl.DescBuilder{
			GoPackagePath: reflect.TypeOf(x{}).PkgPath(),
			RawDescriptor: unsafe.Slice(unsafe.StringData(file_cmd_protoc_gen_go_testdata_imports_test_import_all_proto_rawDesc), len(file_cmd_protoc_gen_go_testdata_imports_test_import_all_proto_rawDesc)),
			NumEnums:      0,
			NumMessages:   1,
			NumExtensions: 0,
			NumServices:   0,
		},
		GoTypes:           file_cmd_protoc_gen_go_testdata_imports_test_import_all_proto_goTypes,
		DependencyIndexes: file_cmd_protoc_gen_go_testdata_imports_test_import_all_proto_depIdxs,
		MessageInfos:      file_cmd_protoc_gen_go_testdata_imports_test_import_all_proto_msgTypes,
	}.Build()
	File_cmd_protoc_gen_go_testdata_imports_test_import_all_proto = out.File
	file_cmd_protoc_gen_go_testdata_imports_test_import_all_proto_goTypes = nil
	file_cmd_protoc_gen_go_testdata_imports_test_import_all_proto_depIdxs = nil
}
