// Copyright 2024 The Go Authors. All rights reserved.
// Use of this source code is governed by a BSD-style
// license that can be found in the LICENSE file.

syntax = "proto2";

package lazy_normalized_wire_test;

option go_package = "google.golang.org/protobuf/internal/testprotos/lazy";

message FSub {
  optional uint32 b = 2;
  optional uint32 c = 3;
  optional FSub grandchild = 4 [lazy = true];
}

message FTop {
  optional uint32 a = 1;
  optional FSub child = 2;
}
