// Copyright 2018 The Go Authors. All rights reserved.
// Use of this source code is governed by a BSD-style
// license that can be found in the LICENSE file.

syntax = "proto3";

package hybrid.goproto.proto.test3;

option go_package = "google.golang.org/protobuf/internal/testprotos/test3/test3_hybrid";


message ImportMessage {}

enum ImportEnum {
  IMPORT_ZERO = 0;
}