// Copyright 2020 The Go Authors. All rights reserved.
// Use of this source code is governed by a BSD-style
// license that can be found in the LICENSE file.

// Code generated by protoc-gen-go. DO NOT EDIT.
// source: cmd/protoc-gen-go/testdata/retention/retention.proto

package retention

import (
	protoreflect "google.golang.org/protobuf/reflect/protoreflect"
	protoimpl "google.golang.org/protobuf/runtime/protoimpl"
	descriptorpb "google.golang.org/protobuf/types/descriptorpb"
	reflect "reflect"
	sync "sync"
	unsafe "unsafe"
)

type TopLevelEnum int32

const (
	TopLevelEnum_TOP_LEVEL_UNKNOWN TopLevelEnum = 0
)

// Enum value maps for TopLevelEnum.
var (
	TopLevelEnum_name = map[int32]string{
		0: "TOP_LEVEL_UNKNOWN",
	}
	TopLevelEnum_value = map[string]int32{
		"TOP_LEVEL_UNKNOWN": 0,
	}
)

func (x TopLevelEnum) Enum() *TopLevelEnum {
	p := new(TopLevelEnum)
	*p = x
	return p
}

func (x TopLevelEnum) String() string {
	return protoimpl.X.EnumStringOf(x.Descriptor(), protoreflect.EnumNumber(x))
}

func (TopLevelEnum) Descriptor() protoreflect.EnumDescriptor {
	return file_cmd_protoc_gen_go_testdata_retention_retention_proto_enumTypes[0].Descriptor()
}

func (TopLevelEnum) Type() protoreflect.EnumType {
	return &file_cmd_protoc_gen_go_testdata_retention_retention_proto_enumTypes[0]
}

func (x TopLevelEnum) Number() protoreflect.EnumNumber {
	return protoreflect.EnumNumber(x)
}

// Deprecated: Do not use.
func (x *TopLevelEnum) UnmarshalJSON(b []byte) error {
	num, err := protoimpl.X.UnmarshalJSONEnum(x.Descriptor(), b)
	if err != nil {
		return err
	}
	*x = TopLevelEnum(num)
	return nil
}

// Deprecated: Use TopLevelEnum.Descriptor instead.
func (TopLevelEnum) EnumDescriptor() ([]byte, []int) {
	return file_cmd_protoc_gen_go_testdata_retention_retention_proto_rawDescGZIP(), []int{0}
}

type TopLevelMessage_NestedEnum int32

const (
	TopLevelMessage_NESTED_UNKNOWN TopLevelMessage_NestedEnum = 0
)

// Enum value maps for TopLevelMessage_NestedEnum.
var (
	TopLevelMessage_NestedEnum_name = map[int32]string{
		0: "NESTED_UNKNOWN",
	}
	TopLevelMessage_NestedEnum_value = map[string]int32{
		"NESTED_UNKNOWN": 0,
	}
)

func (x TopLevelMessage_NestedEnum) Enum() *TopLevelMessage_NestedEnum {
	p := new(TopLevelMessage_NestedEnum)
	*p = x
	return p
}

func (x TopLevelMessage_NestedEnum) String() string {
	return protoimpl.X.EnumStringOf(x.Descriptor(), protoreflect.EnumNumber(x))
}

func (TopLevelMessage_NestedEnum) Descriptor() protoreflect.EnumDescriptor {
	return file_cmd_protoc_gen_go_testdata_retention_retention_proto_enumTypes[1].Descriptor()
}

func (TopLevelMessage_NestedEnum) Type() protoreflect.EnumType {
	return &file_cmd_protoc_gen_go_testdata_retention_retention_proto_enumTypes[1]
}

func (x TopLevelMessage_NestedEnum) Number() protoreflect.EnumNumber {
	return protoreflect.EnumNumber(x)
}

// Deprecated: Do not use.
func (x *TopLevelMessage_NestedEnum) UnmarshalJSON(b []byte) error {
	num, err := protoimpl.X.UnmarshalJSONEnum(x.Descriptor(), b)
	if err != nil {
		return err
	}
	*x = TopLevelMessage_NestedEnum(num)
	return nil
}

// Deprecated: Use TopLevelMessage_NestedEnum.Descriptor instead.
func (TopLevelMessage_NestedEnum) EnumDescriptor() ([]byte, []int) {
	return file_cmd_protoc_gen_go_testdata_retention_retention_proto_rawDescGZIP(), []int{1, 0}
}

type Extendee struct {
	state           protoimpl.MessageState `protogen:"open.v1"`
	extensionFields protoimpl.ExtensionFields
	unknownFields   protoimpl.UnknownFields
	sizeCache       protoimpl.SizeCache
}

func (x *Extendee) Reset() {
	*x = Extendee{}
	mi := &file_cmd_protoc_gen_go_testdata_retention_retention_proto_msgTypes[0]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *Extendee) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*Extendee) ProtoMessage() {}

func (x *Extendee) ProtoReflect() protoreflect.Message {
	mi := &file_cmd_protoc_gen_go_testdata_retention_retention_proto_msgTypes[0]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use Extendee.ProtoReflect.Descriptor instead.
func (*Extendee) Descriptor() ([]byte, []int) {
	return file_cmd_protoc_gen_go_testdata_retention_retention_proto_rawDescGZIP(), []int{0}
}

type TopLevelMessage struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	F     *float32               `protobuf:"fixed32,1,opt,name=f" json:"f,omitempty"`
	// Types that are valid to be assigned to O:
	//
	//	*TopLevelMessage_I
	O               isTopLevelMessage_O `protobuf_oneof:"o"`
	extensionFields protoimpl.ExtensionFields
	unknownFields   protoimpl.UnknownFields
	sizeCache       protoimpl.SizeCache
}

func (x *TopLevelMessage) Reset() {
	*x = TopLevelMessage{}
	mi := &file_cmd_protoc_gen_go_testdata_retention_retention_proto_msgTypes[1]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *TopLevelMessage) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*TopLevelMessage) ProtoMessage() {}

func (x *TopLevelMessage) ProtoReflect() protoreflect.Message {
	mi := &file_cmd_protoc_gen_go_testdata_retention_retention_proto_msgTypes[1]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use TopLevelMessage.ProtoReflect.Descriptor instead.
func (*TopLevelMessage) Descriptor() ([]byte, []int) {
	return file_cmd_protoc_gen_go_testdata_retention_retention_proto_rawDescGZIP(), []int{1}
}

func (x *TopLevelMessage) GetF() float32 {
	if x != nil && x.F != nil {
		return *x.F
	}
	return 0
}

func (x *TopLevelMessage) GetO() isTopLevelMessage_O {
	if x != nil {
		return x.O
	}
	return nil
}

func (x *TopLevelMessage) GetI() int64 {
	if x != nil {
		if x, ok := x.O.(*TopLevelMessage_I); ok {
			return x.I
		}
	}
	return 0
}

type isTopLevelMessage_O interface {
	isTopLevelMessage_O()
}

type TopLevelMessage_I struct {
	I int64 `protobuf:"varint,2,opt,name=i,oneof"`
}

func (*TopLevelMessage_I) isTopLevelMessage_O() {}

type TopLevelMessage_NestedMessage struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *TopLevelMessage_NestedMessage) Reset() {
	*x = TopLevelMessage_NestedMessage{}
	mi := &file_cmd_protoc_gen_go_testdata_retention_retention_proto_msgTypes[2]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *TopLevelMessage_NestedMessage) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*TopLevelMessage_NestedMessage) ProtoMessage() {}

func (x *TopLevelMessage_NestedMessage) ProtoReflect() protoreflect.Message {
	mi := &file_cmd_protoc_gen_go_testdata_retention_retention_proto_msgTypes[2]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use TopLevelMessage_NestedMessage.ProtoReflect.Descriptor instead.
func (*TopLevelMessage_NestedMessage) Descriptor() ([]byte, []int) {
	return file_cmd_protoc_gen_go_testdata_retention_retention_proto_rawDescGZIP(), []int{1, 0}
}

var file_cmd_protoc_gen_go_testdata_retention_retention_proto_extTypes = []protoimpl.ExtensionInfo{
	{
		ExtendedType:  (*descriptorpb.FileOptions)(nil),
		ExtensionType: (*int32)(nil),
		Field:         505092806,
		Name:          "testretention.plain_option",
		Tag:           "varint,505092806,opt,name=plain_option",
		Filename:      "cmd/protoc-gen-go/testdata/retention/retention.proto",
	},
	{
		ExtendedType:  (*descriptorpb.FileOptions)(nil),
		ExtensionType: (*int32)(nil),
		Field:         505039132,
		Name:          "testretention.runtime_retention_option",
		Tag:           "varint,505039132,opt,name=runtime_retention_option",
		Filename:      "cmd/protoc-gen-go/testdata/retention/retention.proto",
	},
	{
		ExtendedType:  (*descriptorpb.FileOptions)(nil),
		ExtensionType: (*int32)(nil),
		Field:         504878676,
		Name:          "testretention.source_retention_option",
		Tag:           "varint,504878676,opt,name=source_retention_option",
		Filename:      "cmd/protoc-gen-go/testdata/retention/retention.proto",
	},
	{
		ExtendedType:  (*descriptorpb.FileOptions)(nil),
		ExtensionType: ([]*OptionsMessage)(nil),
		Field:         504823570,
		Name:          "testretention.repeated_options",
		Tag:           "bytes,504823570,rep,name=repeated_options",
		Filename:      "cmd/protoc-gen-go/testdata/retention/retention.proto",
	},
	{
		ExtendedType:  (*descriptorpb.ExtensionRangeOptions)(nil),
		ExtensionType: (*OptionsMessage)(nil),
		Field:         504822148,
		Name:          "testretention.extension_range_option",
		Tag:           "bytes,504822148,opt,name=extension_range_option",
		Filename:      "cmd/protoc-gen-go/testdata/retention/retention.proto",
	},
	{
		ExtendedType:  (*descriptorpb.MessageOptions)(nil),
		ExtensionType: (*OptionsMessage)(nil),
		Field:         504820819,
		Name:          "testretention.message_option",
		Tag:           "bytes,504820819,opt,name=message_option",
		Filename:      "cmd/protoc-gen-go/testdata/retention/retention.proto",
	},
	{
		ExtendedType:  (*descriptorpb.FieldOptions)(nil),
		ExtensionType: (*OptionsMessage)(nil),
		Field:         504589219,
		Name:          "testretention.field_option",
		Tag:           "bytes,504589219,opt,name=field_option",
		Filename:      "cmd/protoc-gen-go/testdata/retention/retention.proto",
	},
	{
		ExtendedType:  (*descriptorpb.OneofOptions)(nil),
		ExtensionType: (*OptionsMessage)(nil),
		Field:         504479153,
		Name:          "testretention.oneof_option",
		Tag:           "bytes,504479153,opt,name=oneof_option",
		Filename:      "cmd/protoc-gen-go/testdata/retention/retention.proto",
	},
	{
		ExtendedType:  (*descriptorpb.EnumOptions)(nil),
		ExtensionType: (*OptionsMessage)(nil),
		Field:         504451567,
		Name:          "testretention.enum_option",
		Tag:           "bytes,504451567,opt,name=enum_option",
		Filename:      "cmd/protoc-gen-go/testdata/retention/retention.proto",
	},
	{
		ExtendedType:  (*descriptorpb.EnumValueOptions)(nil),
		ExtensionType: (*OptionsMessage)(nil),
		Field:         504450522,
		Name:          "testretention.enum_entry_option",
		Tag:           "bytes,504450522,opt,name=enum_entry_option",
		Filename:      "cmd/protoc-gen-go/testdata/retention/retention.proto",
	},
	{
		ExtendedType:  (*descriptorpb.ServiceOptions)(nil),
		ExtensionType: (*OptionsMessage)(nil),
		Field:         504387709,
		Name:          "testretention.service_option",
		Tag:           "bytes,504387709,opt,name=service_option",
		Filename:      "cmd/protoc-gen-go/testdata/retention/retention.proto",
	},
	{
		ExtendedType:  (*descriptorpb.MethodOptions)(nil),
		ExtensionType: (*OptionsMessage)(nil),
		Field:         504349420,
		Name:          "testretention.method_option",
		Tag:           "bytes,504349420,opt,name=method_option",
		Filename:      "cmd/protoc-gen-go/testdata/retention/retention.proto",
	},
	{
		ExtendedType:  (*Extendee)(nil),
		ExtensionType: (*int32)(nil),
		Field:         1,
		Name:          "testretention.i",
		Tag:           "varint,1,opt,name=i",
		Filename:      "cmd/protoc-gen-go/testdata/retention/retention.proto",
	},
	{
		ExtendedType:  (*Extendee)(nil),
		ExtensionType: (*string)(nil),
		Field:         2,
		Name:          "testretention.TopLevelMessage.s",
		Tag:           "bytes,2,opt,name=s",
		Filename:      "cmd/protoc-gen-go/testdata/retention/retention.proto",
	},
}

// Extension fields to descriptorpb.FileOptions.
var (
	// optional int32 plain_option = 505092806;
	E_PlainOption = &file_cmd_protoc_gen_go_testdata_retention_retention_proto_extTypes[0]
	// optional int32 runtime_retention_option = 505039132;
	E_RuntimeRetentionOption = &file_cmd_protoc_gen_go_testdata_retention_retention_proto_extTypes[1]
	// optional int32 source_retention_option = 504878676;
	E_SourceRetentionOption = &file_cmd_protoc_gen_go_testdata_retention_retention_proto_extTypes[2]
	// repeated testretention.OptionsMessage repeated_options = 504823570;
	E_RepeatedOptions = &file_cmd_protoc_gen_go_testdata_retention_retention_proto_extTypes[3]
)

// Extension fields to descriptorpb.ExtensionRangeOptions.
var (
	// optional testretention.OptionsMessage extension_range_option = 504822148;
	E_ExtensionRangeOption = &file_cmd_protoc_gen_go_testdata_retention_retention_proto_extTypes[4]
)

// Extension fields to descriptorpb.MessageOptions.
var (
	// optional testretention.OptionsMessage message_option = 504820819;
	E_MessageOption = &file_cmd_protoc_gen_go_testdata_retention_retention_proto_extTypes[5]
)

// Extension fields to descriptorpb.FieldOptions.
var (
	// optional testretention.OptionsMessage field_option = 504589219;
	E_FieldOption = &file_cmd_protoc_gen_go_testdata_retention_retention_proto_extTypes[6]
)

// Extension fields to descriptorpb.OneofOptions.
var (
	// optional testretention.OptionsMessage oneof_option = 504479153;
	E_OneofOption = &file_cmd_protoc_gen_go_testdata_retention_retention_proto_extTypes[7]
)

// Extension fields to descriptorpb.EnumOptions.
var (
	// optional testretention.OptionsMessage enum_option = 504451567;
	E_EnumOption = &file_cmd_protoc_gen_go_testdata_retention_retention_proto_extTypes[8]
)

// Extension fields to descriptorpb.EnumValueOptions.
var (
	// optional testretention.OptionsMessage enum_entry_option = 504450522;
	E_EnumEntryOption = &file_cmd_protoc_gen_go_testdata_retention_retention_proto_extTypes[9]
)

// Extension fields to descriptorpb.ServiceOptions.
var (
	// optional testretention.OptionsMessage service_option = 504387709;
	E_ServiceOption = &file_cmd_protoc_gen_go_testdata_retention_retention_proto_extTypes[10]
)

// Extension fields to descriptorpb.MethodOptions.
var (
	// optional testretention.OptionsMessage method_option = 504349420;
	E_MethodOption = &file_cmd_protoc_gen_go_testdata_retention_retention_proto_extTypes[11]
)

// Extension fields to Extendee.
var (
	// optional int32 i = 1;
	E_I = &file_cmd_protoc_gen_go_testdata_retention_retention_proto_extTypes[12]
	// optional string s = 2;
	E_TopLevelMessage_S = &file_cmd_protoc_gen_go_testdata_retention_retention_proto_extTypes[13]
)

var File_cmd_protoc_gen_go_testdata_retention_retention_proto protoreflect.FileDescriptor

const file_cmd_protoc_gen_go_testdata_retention_retention_proto_rawDesc = "" +
	"\n" +
	"4cmd/protoc-gen-go/testdata/retention/retention.proto\x12\rtestretention\x1a:cmd/protoc-gen-go/testdata/retention/options_message.proto\x1a google/protobuf/descriptor.proto\"\x16\n" +
	"\bExtendee*\x04\b\x01\x10\x02*\x04\b\x02\x10\x03\"\xe8\x01\n" +
	"\x0fTopLevelMessage\x12\x18\n" +
	"\x01f\x18\x01 \x01(\x02B\n" +
	"\x9a\xba\xed\x84\x0f\x04\b\x01\x10\x02R\x01f\x12\x0e\n" +
	"\x01i\x18\x02 \x01(\x03H\x00R\x01i\x1a\x1b\n" +
	"\rNestedMessage:\n" +
	"\x9a\xc5ޅ\x0f\x04\b\x01\x10\x02\",\n" +
	"\n" +
	"NestedEnum\x12\x12\n" +
	"\x0eNESTED_UNKNOWN\x10\x00\x1a\n" +
	"\xfa\x9e\xaa\x84\x0f\x04\b\x01\x10\x02*\x10\b\n" +
	"\x10e\x1a\n" +
	"\xa2\x98߅\x0f\x04\b\x01\x10\x0221\n" +
	"\x01s\x12\x17.testretention.Extendee\x18\x02 \x01(\tB\n" +
	"\x9a\xba\xed\x84\x0f\x04\b\x01\x10\x02R\x01s:\n" +
	"\x9a\xc5ޅ\x0f\x04\b\x01\x10\x02B\x0f\n" +
	"\x01o\x12\n" +
	"\x8a۷\x84\x0f\x04\b\x01\x10\x02*=\n" +
	"\fTopLevelEnum\x12!\n" +
	"\x11TOP_LEVEL_UNKNOWN\x10\x00\x1a\n" +
	"\xd2ݩ\x84\x0f\x04\b\x01\x10\x02\x1a\n" +
	"\xfa\x9e\xaa\x84\x0f\x04\b\x01\x10\x022l\n" +
	"\aService\x12U\n" +
	"\aDoStuff\x12\x1e.testretention.TopLevelMessage\x1a\x1e.testretention.TopLevelMessage\"\n" +
	"\xe2\xae\xf8\x83\x0f\x04\b\x01\x10\x02\x1a\n" +
	"ꇋ\x84\x0f\x04\b\x01\x10\x02:C\n" +
	"\fplain_option\x12\x1c.google.protobuf.FileOptions\x18Ƶ\xec\xf0\x01 \x01(\x05R\vplainOption:_\n" +
	"\x18runtime_retention_option\x12\x1c.google.protobuf.FileOptions\x18\x9c\x92\xe9\xf0\x01 \x01(\x05B\x03\x88\x01\x01R\x16runtimeRetentionOption:]\n" +
	"\x17source_retention_option\x12\x1c.google.protobuf.FileOptions\x18Ԭ\xdf\xf0\x01 \x01(\x05B\x03\x88\x01\x02R\x15sourceRetentionOption:j\n" +
	"\x10repeated_options\x12\x1c.google.protobuf.FileOptions\x18\x92\xfe\xdb\xf0\x01 \x03(\v2\x1d.testretention.OptionsMessageR\x0frepeatedOptions:\x7f\n" +
	"\x16extension_range_option\x12&.google.protobuf.ExtensionRangeOptions\x18\x84\xf3\xdb\xf0\x01 \x01(\v2\x1d.testretention.OptionsMessageR\x14extensionRangeOption:i\n" +
	"\x0emessage_option\x12\x1f.google.protobuf.MessageOptions\x18\xd3\xe8\xdb\xf0\x01 \x01(\v2\x1d.testretention.OptionsMessageR\rmessageOption:c\n" +
	"\ffield_option\x12\x1d.google.protobuf.FieldOptions\x18\xa3\xd7\xcd\xf0\x01 \x01(\v2\x1d.testretention.OptionsMessageR\vfieldOption:c\n" +
	"\foneof_option\x12\x1d.google.protobuf.OneofOptions\x18\xb1\xfb\xc6\xf0\x01 \x01(\v2\x1d.testretention.OptionsMessageR\voneofOption:`\n" +
	"\venum_option\x12\x1c.google.protobuf.EnumOptions\x18\xef\xa3\xc5\xf0\x01 \x01(\v2\x1d.testretention.OptionsMessageR\n" +
	"enumOption:p\n" +
	"\x11enum_entry_option\x12!.google.protobuf.EnumValueOptions\x18ڛ\xc5\xf0\x01 \x01(\v2\x1d.testretention.OptionsMessageR\x0fenumEntryOption:i\n" +
	"\x0eservice_option\x12\x1f.google.protobuf.ServiceOptions\x18\xfd\xb0\xc1\xf0\x01 \x01(\v2\x1d.testretention.OptionsMessageR\rserviceOption:f\n" +
	"\rmethod_option\x12\x1e.google.protobuf.MethodOptions\x18셿\xf0\x01 \x01(\v2\x1d.testretention.OptionsMessageR\fmethodOption:1\n" +
	"\x01i\x12\x17.testretention.Extendee\x18\x01 \x01(\x05B\n" +
	"\x9a\xba\xed\x84\x0f\x04\b\x01\x10\x02R\x01iBm\x92\xf1߅\x0f\x04\b\x01\x10\x02\x82\x90\xf7\x85\x0f\x04\b\x01\x10\x02\xe0\x91Ɇ\x0f\x02\xb0\xac\xe3\x86\x0f\x01\x80\x9b\xb2\xa0\x0f\x01Ю\xfc\xa2\x0f\x02Z?google.golang.org/protobuf/cmd/protoc-gen-go/testdata/retention"

var (
	file_cmd_protoc_gen_go_testdata_retention_retention_proto_rawDescOnce sync.Once
	file_cmd_protoc_gen_go_testdata_retention_retention_proto_rawDescData []byte
)

func file_cmd_protoc_gen_go_testdata_retention_retention_proto_rawDescGZIP() []byte {
	file_cmd_protoc_gen_go_testdata_retention_retention_proto_rawDescOnce.Do(func() {
		file_cmd_protoc_gen_go_testdata_retention_retention_proto_rawDescData = protoimpl.X.CompressGZIP(unsafe.Slice(unsafe.StringData(file_cmd_protoc_gen_go_testdata_retention_retention_proto_rawDesc), len(file_cmd_protoc_gen_go_testdata_retention_retention_proto_rawDesc)))
	})
	return file_cmd_protoc_gen_go_testdata_retention_retention_proto_rawDescData
}

var file_cmd_protoc_gen_go_testdata_retention_retention_proto_enumTypes = make([]protoimpl.EnumInfo, 2)
var file_cmd_protoc_gen_go_testdata_retention_retention_proto_msgTypes = make([]protoimpl.MessageInfo, 3)
var file_cmd_protoc_gen_go_testdata_retention_retention_proto_goTypes = []any{
	(TopLevelEnum)(0),                          // 0: testretention.TopLevelEnum
	(TopLevelMessage_NestedEnum)(0),            // 1: testretention.TopLevelMessage.NestedEnum
	(*Extendee)(nil),                           // 2: testretention.Extendee
	(*TopLevelMessage)(nil),                    // 3: testretention.TopLevelMessage
	(*TopLevelMessage_NestedMessage)(nil),      // 4: testretention.TopLevelMessage.NestedMessage
	(*descriptorpb.FileOptions)(nil),           // 5: google.protobuf.FileOptions
	(*descriptorpb.ExtensionRangeOptions)(nil), // 6: google.protobuf.ExtensionRangeOptions
	(*descriptorpb.MessageOptions)(nil),        // 7: google.protobuf.MessageOptions
	(*descriptorpb.FieldOptions)(nil),          // 8: google.protobuf.FieldOptions
	(*descriptorpb.OneofOptions)(nil),          // 9: google.protobuf.OneofOptions
	(*descriptorpb.EnumOptions)(nil),           // 10: google.protobuf.EnumOptions
	(*descriptorpb.EnumValueOptions)(nil),      // 11: google.protobuf.EnumValueOptions
	(*descriptorpb.ServiceOptions)(nil),        // 12: google.protobuf.ServiceOptions
	(*descriptorpb.MethodOptions)(nil),         // 13: google.protobuf.MethodOptions
	(*OptionsMessage)(nil),                     // 14: testretention.OptionsMessage
}
var file_cmd_protoc_gen_go_testdata_retention_retention_proto_depIdxs = []int32{
	5,  // 0: testretention.plain_option:extendee -> google.protobuf.FileOptions
	5,  // 1: testretention.runtime_retention_option:extendee -> google.protobuf.FileOptions
	5,  // 2: testretention.source_retention_option:extendee -> google.protobuf.FileOptions
	5,  // 3: testretention.repeated_options:extendee -> google.protobuf.FileOptions
	6,  // 4: testretention.extension_range_option:extendee -> google.protobuf.ExtensionRangeOptions
	7,  // 5: testretention.message_option:extendee -> google.protobuf.MessageOptions
	8,  // 6: testretention.field_option:extendee -> google.protobuf.FieldOptions
	9,  // 7: testretention.oneof_option:extendee -> google.protobuf.OneofOptions
	10, // 8: testretention.enum_option:extendee -> google.protobuf.EnumOptions
	11, // 9: testretention.enum_entry_option:extendee -> google.protobuf.EnumValueOptions
	12, // 10: testretention.service_option:extendee -> google.protobuf.ServiceOptions
	13, // 11: testretention.method_option:extendee -> google.protobuf.MethodOptions
	2,  // 12: testretention.i:extendee -> testretention.Extendee
	2,  // 13: testretention.TopLevelMessage.s:extendee -> testretention.Extendee
	14, // 14: testretention.repeated_options:type_name -> testretention.OptionsMessage
	14, // 15: testretention.extension_range_option:type_name -> testretention.OptionsMessage
	14, // 16: testretention.message_option:type_name -> testretention.OptionsMessage
	14, // 17: testretention.field_option:type_name -> testretention.OptionsMessage
	14, // 18: testretention.oneof_option:type_name -> testretention.OptionsMessage
	14, // 19: testretention.enum_option:type_name -> testretention.OptionsMessage
	14, // 20: testretention.enum_entry_option:type_name -> testretention.OptionsMessage
	14, // 21: testretention.service_option:type_name -> testretention.OptionsMessage
	14, // 22: testretention.method_option:type_name -> testretention.OptionsMessage
	3,  // 23: testretention.Service.DoStuff:input_type -> testretention.TopLevelMessage
	3,  // 24: testretention.Service.DoStuff:output_type -> testretention.TopLevelMessage
	24, // [24:25] is the sub-list for method output_type
	23, // [23:24] is the sub-list for method input_type
	14, // [14:23] is the sub-list for extension type_name
	0,  // [0:14] is the sub-list for extension extendee
	0,  // [0:0] is the sub-list for field type_name
}

func init() { file_cmd_protoc_gen_go_testdata_retention_retention_proto_init() }
func file_cmd_protoc_gen_go_testdata_retention_retention_proto_init() {
	if File_cmd_protoc_gen_go_testdata_retention_retention_proto != nil {
		return
	}
	file_cmd_protoc_gen_go_testdata_retention_options_message_proto_init()
	file_cmd_protoc_gen_go_testdata_retention_retention_proto_msgTypes[1].OneofWrappers = []any{
		(*TopLevelMessage_I)(nil),
	}
	type x struct{}
	out := protoimpl.TypeBuilder{
		File: protoimpl.DescBuilder{
			GoPackagePath: reflect.TypeOf(x{}).PkgPath(),
			RawDescriptor: unsafe.Slice(unsafe.StringData(file_cmd_protoc_gen_go_testdata_retention_retention_proto_rawDesc), len(file_cmd_protoc_gen_go_testdata_retention_retention_proto_rawDesc)),
			NumEnums:      2,
			NumMessages:   3,
			NumExtensions: 14,
			NumServices:   1,
		},
		GoTypes:           file_cmd_protoc_gen_go_testdata_retention_retention_proto_goTypes,
		DependencyIndexes: file_cmd_protoc_gen_go_testdata_retention_retention_proto_depIdxs,
		EnumInfos:         file_cmd_protoc_gen_go_testdata_retention_retention_proto_enumTypes,
		MessageInfos:      file_cmd_protoc_gen_go_testdata_retention_retention_proto_msgTypes,
		ExtensionInfos:    file_cmd_protoc_gen_go_testdata_retention_retention_proto_extTypes,
	}.Build()
	File_cmd_protoc_gen_go_testdata_retention_retention_proto = out.File
	file_cmd_protoc_gen_go_testdata_retention_retention_proto_goTypes = nil
	file_cmd_protoc_gen_go_testdata_retention_retention_proto_depIdxs = nil
}
