// Copyright 2019 The Go Authors. All rights reserved.
// Use of this source code is governed by a BSD-style
// license that can be found in the LICENSE file.

edition = "2023";

package opaque.goproto.proto.messageset;

option go_package = "google.golang.org/protobuf/internal/testprotos/messageset/messagesetpb/messagesetpb_opaque";
import "google/protobuf/go_features.proto";
option features.(pb.go).api_level = API_OPAQUE;

message MessageSet {
  option message_set_wire_format = true;

  extensions 4 to max;
}

message MessageSetContainer {
  MessageSet message_set = 1;
}