// Copyright 2020 The Go Authors. All rights reserved.
// Use of this source code is governed by a BSD-style
// license that can be found in the LICENSE file.

package bug1052_test

import (
	_ "google.golang.org/protobuf/internal/testprotos/legacy/bug1052"
)
