// Copyright 2018 The Go Authors. All rights reserved.
// Use of this source code is governed by a BSD-style
// license that can be found in the LICENSE file.

// Code generated by protoc-gen-go. DO NOT EDIT.
// source: cmd/protoc-gen-go/testdata/import_public/a.proto

package import_public

import (
	sub "google.golang.org/protobuf/cmd/protoc-gen-go/testdata/import_public/sub"
	protoreflect "google.golang.org/protobuf/reflect/protoreflect"
	protoimpl "google.golang.org/protobuf/runtime/protoimpl"
	reflect "reflect"
	sync "sync"
	unsafe "unsafe"
)

// Symbols defined in public import of cmd/protoc-gen-go/testdata/import_public/sub/a.proto.

type E = sub.E

const E_ZERO = sub.E_ZERO

var E_name = sub.E_name
var E_value = sub.E_value

type M_Subenum = sub.M_Subenum

const M_M_ZERO = sub.M_M_ZERO

var M_Subenum_name = sub.M_Subenum_name
var M_Subenum_value = sub.M_Subenum_value

type M_Submessage_Submessage_Subenum = sub.M_Submessage_Submessage_Subenum

const M_Submessage_M_SUBMESSAGE_ZERO = sub.M_Submessage_M_SUBMESSAGE_ZERO

var M_Submessage_Submessage_Subenum_name = sub.M_Submessage_Submessage_Subenum_name
var M_Submessage_Submessage_Subenum_value = sub.M_Submessage_Submessage_Subenum_value

type M = sub.M

const Default_M_S = sub.Default_M_S

var Default_M_B = sub.Default_M_B
var Default_M_F = sub.Default_M_F

type M_OneofInt32 = sub.M_OneofInt32
type M_OneofInt64 = sub.M_OneofInt64
type M_Submessage = sub.M_Submessage
type M_Submessage_SubmessageOneofInt32 = sub.M_Submessage_SubmessageOneofInt32
type M_Submessage_SubmessageOneofInt64 = sub.M_Submessage_SubmessageOneofInt64

var E_ExtensionField = sub.E_ExtensionField

type Public struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	M             *sub.M                 `protobuf:"bytes,1,opt,name=m" json:"m,omitempty"`
	E             *sub.E                 `protobuf:"varint,2,opt,name=e,enum=goproto.protoc.import_public.sub.E" json:"e,omitempty"`
	Local         *Local                 `protobuf:"bytes,3,opt,name=local" json:"local,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *Public) Reset() {
	*x = Public{}
	mi := &file_cmd_protoc_gen_go_testdata_import_public_a_proto_msgTypes[0]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *Public) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*Public) ProtoMessage() {}

func (x *Public) ProtoReflect() protoreflect.Message {
	mi := &file_cmd_protoc_gen_go_testdata_import_public_a_proto_msgTypes[0]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use Public.ProtoReflect.Descriptor instead.
func (*Public) Descriptor() ([]byte, []int) {
	return file_cmd_protoc_gen_go_testdata_import_public_a_proto_rawDescGZIP(), []int{0}
}

func (x *Public) GetM() *sub.M {
	if x != nil {
		return x.M
	}
	return nil
}

func (x *Public) GetE() sub.E {
	if x != nil && x.E != nil {
		return *x.E
	}
	return sub.E(0)
}

func (x *Public) GetLocal() *Local {
	if x != nil {
		return x.Local
	}
	return nil
}

var File_cmd_protoc_gen_go_testdata_import_public_a_proto protoreflect.FileDescriptor

const file_cmd_protoc_gen_go_testdata_import_public_a_proto_rawDesc = "" +
	"\n" +
	"0cmd/protoc-gen-go/testdata/import_public/a.proto\x12\x1cgoproto.protoc.import_public\x1a0cmd/protoc-gen-go/testdata/import_public/b.proto\x1a4cmd/protoc-gen-go/testdata/import_public/sub/a.proto\"\xa9\x01\n" +
	"\x06Public\x121\n" +
	"\x01m\x18\x01 \x01(\v2#.goproto.protoc.import_public.sub.MR\x01m\x121\n" +
	"\x01e\x18\x02 \x01(\x0e2#.goproto.protoc.import_public.sub.ER\x01e\x129\n" +
	"\x05local\x18\x03 \x01(\v2#.goproto.protoc.import_public.LocalR\x05localBEZCgoogle.golang.org/protobuf/cmd/protoc-gen-go/testdata/import_publicP\x00P\x01"

var (
	file_cmd_protoc_gen_go_testdata_import_public_a_proto_rawDescOnce sync.Once
	file_cmd_protoc_gen_go_testdata_import_public_a_proto_rawDescData []byte
)

func file_cmd_protoc_gen_go_testdata_import_public_a_proto_rawDescGZIP() []byte {
	file_cmd_protoc_gen_go_testdata_import_public_a_proto_rawDescOnce.Do(func() {
		file_cmd_protoc_gen_go_testdata_import_public_a_proto_rawDescData = protoimpl.X.CompressGZIP(unsafe.Slice(unsafe.StringData(file_cmd_protoc_gen_go_testdata_import_public_a_proto_rawDesc), len(file_cmd_protoc_gen_go_testdata_import_public_a_proto_rawDesc)))
	})
	return file_cmd_protoc_gen_go_testdata_import_public_a_proto_rawDescData
}

var file_cmd_protoc_gen_go_testdata_import_public_a_proto_msgTypes = make([]protoimpl.MessageInfo, 1)
var file_cmd_protoc_gen_go_testdata_import_public_a_proto_goTypes = []any{
	(*Public)(nil), // 0: goproto.protoc.import_public.Public
	(*sub.M)(nil),  // 1: goproto.protoc.import_public.sub.M
	(sub.E)(0),     // 2: goproto.protoc.import_public.sub.E
	(*Local)(nil),  // 3: goproto.protoc.import_public.Local
}
var file_cmd_protoc_gen_go_testdata_import_public_a_proto_depIdxs = []int32{
	1, // 0: goproto.protoc.import_public.Public.m:type_name -> goproto.protoc.import_public.sub.M
	2, // 1: goproto.protoc.import_public.Public.e:type_name -> goproto.protoc.import_public.sub.E
	3, // 2: goproto.protoc.import_public.Public.local:type_name -> goproto.protoc.import_public.Local
	3, // [3:3] is the sub-list for method output_type
	3, // [3:3] is the sub-list for method input_type
	3, // [3:3] is the sub-list for extension type_name
	3, // [3:3] is the sub-list for extension extendee
	0, // [0:3] is the sub-list for field type_name
}

func init() { file_cmd_protoc_gen_go_testdata_import_public_a_proto_init() }
func file_cmd_protoc_gen_go_testdata_import_public_a_proto_init() {
	if File_cmd_protoc_gen_go_testdata_import_public_a_proto != nil {
		return
	}
	file_cmd_protoc_gen_go_testdata_import_public_b_proto_init()
	type x struct{}
	out := protoimpl.TypeBuilder{
		File: protoimpl.DescBuilder{
			GoPackagePath: reflect.TypeOf(x{}).PkgPath(),
			RawDescriptor: unsafe.Slice(unsafe.StringData(file_cmd_protoc_gen_go_testdata_import_public_a_proto_rawDesc), len(file_cmd_protoc_gen_go_testdata_import_public_a_proto_rawDesc)),
			NumEnums:      0,
			NumMessages:   1,
			NumExtensions: 0,
			NumServices:   0,
		},
		GoTypes:           file_cmd_protoc_gen_go_testdata_import_public_a_proto_goTypes,
		DependencyIndexes: file_cmd_protoc_gen_go_testdata_import_public_a_proto_depIdxs,
		MessageInfos:      file_cmd_protoc_gen_go_testdata_import_public_a_proto_msgTypes,
	}.Build()
	File_cmd_protoc_gen_go_testdata_import_public_a_proto = out.File
	file_cmd_protoc_gen_go_testdata_import_public_a_proto_goTypes = nil
	file_cmd_protoc_gen_go_testdata_import_public_a_proto_depIdxs = nil
}
