// Copyright 2024 The Go Authors. All rights reserved.
// Use of this source code is governed by a BSD-style
// license that can be found in the LICENSE file.

// Code generated by protoc-gen-go. DO NOT EDIT.
// source: cmd/protoc-gen-go/testdata/protoeditions/nested_messages.proto

package protoeditions

import (
	protoreflect "google.golang.org/protobuf/reflect/protoreflect"
	protoimpl "google.golang.org/protobuf/runtime/protoimpl"
	reflect "reflect"
	sync "sync"
	unsafe "unsafe"
)

type Layer1 struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	L2            *Layer1_Layer2         `protobuf:"bytes,1,opt,name=l2" json:"l2,omitempty"`
	L3            *Layer1_Layer2_Layer3  `protobuf:"bytes,2,opt,name=l3" json:"l3,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *Layer1) Reset() {
	*x = Layer1{}
	mi := &file_cmd_protoc_gen_go_testdata_protoeditions_nested_messages_proto_msgTypes[0]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *Layer1) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*Layer1) ProtoMessage() {}

func (x *Layer1) ProtoReflect() protoreflect.Message {
	mi := &file_cmd_protoc_gen_go_testdata_protoeditions_nested_messages_proto_msgTypes[0]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use Layer1.ProtoReflect.Descriptor instead.
func (*Layer1) Descriptor() ([]byte, []int) {
	return file_cmd_protoc_gen_go_testdata_protoeditions_nested_messages_proto_rawDescGZIP(), []int{0}
}

func (x *Layer1) GetL2() *Layer1_Layer2 {
	if x != nil {
		return x.L2
	}
	return nil
}

func (x *Layer1) GetL3() *Layer1_Layer2_Layer3 {
	if x != nil {
		return x.L3
	}
	return nil
}

type Layer1_Layer2 struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	L3            *Layer1_Layer2_Layer3  `protobuf:"bytes,1,opt,name=l3" json:"l3,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *Layer1_Layer2) Reset() {
	*x = Layer1_Layer2{}
	mi := &file_cmd_protoc_gen_go_testdata_protoeditions_nested_messages_proto_msgTypes[1]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *Layer1_Layer2) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*Layer1_Layer2) ProtoMessage() {}

func (x *Layer1_Layer2) ProtoReflect() protoreflect.Message {
	mi := &file_cmd_protoc_gen_go_testdata_protoeditions_nested_messages_proto_msgTypes[1]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use Layer1_Layer2.ProtoReflect.Descriptor instead.
func (*Layer1_Layer2) Descriptor() ([]byte, []int) {
	return file_cmd_protoc_gen_go_testdata_protoeditions_nested_messages_proto_rawDescGZIP(), []int{0, 0}
}

func (x *Layer1_Layer2) GetL3() *Layer1_Layer2_Layer3 {
	if x != nil {
		return x.L3
	}
	return nil
}

type Layer1_Layer2_Layer3 struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *Layer1_Layer2_Layer3) Reset() {
	*x = Layer1_Layer2_Layer3{}
	mi := &file_cmd_protoc_gen_go_testdata_protoeditions_nested_messages_proto_msgTypes[2]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *Layer1_Layer2_Layer3) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*Layer1_Layer2_Layer3) ProtoMessage() {}

func (x *Layer1_Layer2_Layer3) ProtoReflect() protoreflect.Message {
	mi := &file_cmd_protoc_gen_go_testdata_protoeditions_nested_messages_proto_msgTypes[2]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use Layer1_Layer2_Layer3.ProtoReflect.Descriptor instead.
func (*Layer1_Layer2_Layer3) Descriptor() ([]byte, []int) {
	return file_cmd_protoc_gen_go_testdata_protoeditions_nested_messages_proto_rawDescGZIP(), []int{0, 0, 0}
}

var File_cmd_protoc_gen_go_testdata_protoeditions_nested_messages_proto protoreflect.FileDescriptor

const file_cmd_protoc_gen_go_testdata_protoeditions_nested_messages_proto_rawDesc = "" +
	"\n" +
	">cmd/protoc-gen-go/testdata/protoeditions/nested_messages.proto\x12\x1cgoproto.protoc.protoeditions\"\xe1\x01\n" +
	"\x06Layer1\x12;\n" +
	"\x02l2\x18\x01 \x01(\v2+.goproto.protoc.protoeditions.Layer1.Layer2R\x02l2\x12B\n" +
	"\x02l3\x18\x02 \x01(\v22.goproto.protoc.protoeditions.Layer1.Layer2.Layer3R\x02l3\x1aV\n" +
	"\x06Layer2\x12B\n" +
	"\x02l3\x18\x01 \x01(\v22.goproto.protoc.protoeditions.Layer1.Layer2.Layer3R\x02l3\x1a\b\n" +
	"\x06Layer3BEZCgoogle.golang.org/protobuf/cmd/protoc-gen-go/testdata/protoeditionsb\beditionsp\xe8\a"

var (
	file_cmd_protoc_gen_go_testdata_protoeditions_nested_messages_proto_rawDescOnce sync.Once
	file_cmd_protoc_gen_go_testdata_protoeditions_nested_messages_proto_rawDescData []byte
)

func file_cmd_protoc_gen_go_testdata_protoeditions_nested_messages_proto_rawDescGZIP() []byte {
	file_cmd_protoc_gen_go_testdata_protoeditions_nested_messages_proto_rawDescOnce.Do(func() {
		file_cmd_protoc_gen_go_testdata_protoeditions_nested_messages_proto_rawDescData = protoimpl.X.CompressGZIP(unsafe.Slice(unsafe.StringData(file_cmd_protoc_gen_go_testdata_protoeditions_nested_messages_proto_rawDesc), len(file_cmd_protoc_gen_go_testdata_protoeditions_nested_messages_proto_rawDesc)))
	})
	return file_cmd_protoc_gen_go_testdata_protoeditions_nested_messages_proto_rawDescData
}

var file_cmd_protoc_gen_go_testdata_protoeditions_nested_messages_proto_msgTypes = make([]protoimpl.MessageInfo, 3)
var file_cmd_protoc_gen_go_testdata_protoeditions_nested_messages_proto_goTypes = []any{
	(*Layer1)(nil),               // 0: goproto.protoc.protoeditions.Layer1
	(*Layer1_Layer2)(nil),        // 1: goproto.protoc.protoeditions.Layer1.Layer2
	(*Layer1_Layer2_Layer3)(nil), // 2: goproto.protoc.protoeditions.Layer1.Layer2.Layer3
}
var file_cmd_protoc_gen_go_testdata_protoeditions_nested_messages_proto_depIdxs = []int32{
	1, // 0: goproto.protoc.protoeditions.Layer1.l2:type_name -> goproto.protoc.protoeditions.Layer1.Layer2
	2, // 1: goproto.protoc.protoeditions.Layer1.l3:type_name -> goproto.protoc.protoeditions.Layer1.Layer2.Layer3
	2, // 2: goproto.protoc.protoeditions.Layer1.Layer2.l3:type_name -> goproto.protoc.protoeditions.Layer1.Layer2.Layer3
	3, // [3:3] is the sub-list for method output_type
	3, // [3:3] is the sub-list for method input_type
	3, // [3:3] is the sub-list for extension type_name
	3, // [3:3] is the sub-list for extension extendee
	0, // [0:3] is the sub-list for field type_name
}

func init() { file_cmd_protoc_gen_go_testdata_protoeditions_nested_messages_proto_init() }
func file_cmd_protoc_gen_go_testdata_protoeditions_nested_messages_proto_init() {
	if File_cmd_protoc_gen_go_testdata_protoeditions_nested_messages_proto != nil {
		return
	}
	type x struct{}
	out := protoimpl.TypeBuilder{
		File: protoimpl.DescBuilder{
			GoPackagePath: reflect.TypeOf(x{}).PkgPath(),
			RawDescriptor: unsafe.Slice(unsafe.StringData(file_cmd_protoc_gen_go_testdata_protoeditions_nested_messages_proto_rawDesc), len(file_cmd_protoc_gen_go_testdata_protoeditions_nested_messages_proto_rawDesc)),
			NumEnums:      0,
			NumMessages:   3,
			NumExtensions: 0,
			NumServices:   0,
		},
		GoTypes:           file_cmd_protoc_gen_go_testdata_protoeditions_nested_messages_proto_goTypes,
		DependencyIndexes: file_cmd_protoc_gen_go_testdata_protoeditions_nested_messages_proto_depIdxs,
		MessageInfos:      file_cmd_protoc_gen_go_testdata_protoeditions_nested_messages_proto_msgTypes,
	}.Build()
	File_cmd_protoc_gen_go_testdata_protoeditions_nested_messages_proto = out.File
	file_cmd_protoc_gen_go_testdata_protoeditions_nested_messages_proto_goTypes = nil
	file_cmd_protoc_gen_go_testdata_protoeditions_nested_messages_proto_depIdxs = nil
}
