// Copyright 2024 The Go Authors. All rights reserved.
// Use of this source code is governed by a BSD-style
// license that can be found in the LICENSE file.

// Code generated by protoc-gen-go. DO NOT EDIT.
// source: internal/testprotos/lazy/lazy_extension_normalized_wire_test.proto

package lazy

import (
	protoreflect "google.golang.org/protobuf/reflect/protoreflect"
	protoimpl "google.golang.org/protobuf/runtime/protoimpl"
	reflect "reflect"
	sync "sync"
	unsafe "unsafe"
)

type Sub struct {
	state           protoimpl.MessageState `protogen:"open.v1"`
	C               *uint32                `protobuf:"varint,3,opt,name=c" json:"c,omitempty"`
	Grandchild      *Sub                   `protobuf:"bytes,4,opt,name=grandchild" json:"grandchild,omitempty"`
	extensionFields protoimpl.ExtensionFields
	unknownFields   protoimpl.UnknownFields
	sizeCache       protoimpl.SizeCache
}

func (x *Sub) Reset() {
	*x = Sub{}
	mi := &file_internal_testprotos_lazy_lazy_extension_normalized_wire_test_proto_msgTypes[0]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *Sub) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*Sub) ProtoMessage() {}

func (x *Sub) ProtoReflect() protoreflect.Message {
	mi := &file_internal_testprotos_lazy_lazy_extension_normalized_wire_test_proto_msgTypes[0]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use Sub.ProtoReflect.Descriptor instead.
func (*Sub) Descriptor() ([]byte, []int) {
	return file_internal_testprotos_lazy_lazy_extension_normalized_wire_test_proto_rawDescGZIP(), []int{0}
}

func (x *Sub) GetC() uint32 {
	if x != nil && x.C != nil {
		return *x.C
	}
	return 0
}

func (x *Sub) GetGrandchild() *Sub {
	if x != nil {
		return x.Grandchild
	}
	return nil
}

type Top struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	A             *uint32                `protobuf:"varint,1,opt,name=a" json:"a,omitempty"`
	Child         *Sub                   `protobuf:"bytes,2,opt,name=child" json:"child,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *Top) Reset() {
	*x = Top{}
	mi := &file_internal_testprotos_lazy_lazy_extension_normalized_wire_test_proto_msgTypes[1]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *Top) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*Top) ProtoMessage() {}

func (x *Top) ProtoReflect() protoreflect.Message {
	mi := &file_internal_testprotos_lazy_lazy_extension_normalized_wire_test_proto_msgTypes[1]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use Top.ProtoReflect.Descriptor instead.
func (*Top) Descriptor() ([]byte, []int) {
	return file_internal_testprotos_lazy_lazy_extension_normalized_wire_test_proto_rawDescGZIP(), []int{1}
}

func (x *Top) GetA() uint32 {
	if x != nil && x.A != nil {
		return *x.A
	}
	return 0
}

func (x *Top) GetChild() *Sub {
	if x != nil {
		return x.Child
	}
	return nil
}

type Ext struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	SomeFlag      *bool                  `protobuf:"varint,1,opt,name=some_flag,json=someFlag" json:"some_flag,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *Ext) Reset() {
	*x = Ext{}
	mi := &file_internal_testprotos_lazy_lazy_extension_normalized_wire_test_proto_msgTypes[2]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *Ext) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*Ext) ProtoMessage() {}

func (x *Ext) ProtoReflect() protoreflect.Message {
	mi := &file_internal_testprotos_lazy_lazy_extension_normalized_wire_test_proto_msgTypes[2]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use Ext.ProtoReflect.Descriptor instead.
func (*Ext) Descriptor() ([]byte, []int) {
	return file_internal_testprotos_lazy_lazy_extension_normalized_wire_test_proto_rawDescGZIP(), []int{2}
}

func (x *Ext) GetSomeFlag() bool {
	if x != nil && x.SomeFlag != nil {
		return *x.SomeFlag
	}
	return false
}

var file_internal_testprotos_lazy_lazy_extension_normalized_wire_test_proto_extTypes = []protoimpl.ExtensionInfo{
	{
		ExtendedType:  (*Sub)(nil),
		ExtensionType: (*Ext)(nil),
		Field:         2,
		Name:          "lazy_extension_normalized_wire_test.Ext.b",
		Tag:           "bytes,2,opt,name=b",
		Filename:      "internal/testprotos/lazy/lazy_extension_normalized_wire_test.proto",
	},
}

// Extension fields to Sub.
var (
	// optional lazy_extension_normalized_wire_test.Ext b = 2;
	E_Ext_B = &file_internal_testprotos_lazy_lazy_extension_normalized_wire_test_proto_extTypes[0]
)

var File_internal_testprotos_lazy_lazy_extension_normalized_wire_test_proto protoreflect.FileDescriptor

const file_internal_testprotos_lazy_lazy_extension_normalized_wire_test_proto_rawDesc = "" +
	"\n" +
	"Binternal/testprotos/lazy/lazy_extension_normalized_wire_test.proto\x12#lazy_extension_normalized_wire_test\"c\n" +
	"\x03Sub\x12\f\n" +
	"\x01c\x18\x03 \x01(\rR\x01c\x12H\n" +
	"\n" +
	"grandchild\x18\x04 \x01(\v2(.lazy_extension_normalized_wire_test.SubR\n" +
	"grandchild*\x04\b\x02\x10\x03\"S\n" +
	"\x03Top\x12\f\n" +
	"\x01a\x18\x01 \x01(\rR\x01a\x12>\n" +
	"\x05child\x18\x02 \x01(\v2(.lazy_extension_normalized_wire_test.SubR\x05child\"\x84\x01\n" +
	"\x03Ext\x12\x1b\n" +
	"\tsome_flag\x18\x01 \x01(\bR\bsomeFlag2`\n" +
	"\x01b\x12(.lazy_extension_normalized_wire_test.Sub\x18\x02 \x01(\v2(.lazy_extension_normalized_wire_test.ExtR\x01bB5Z3google.golang.org/protobuf/internal/testprotos/lazy"

var (
	file_internal_testprotos_lazy_lazy_extension_normalized_wire_test_proto_rawDescOnce sync.Once
	file_internal_testprotos_lazy_lazy_extension_normalized_wire_test_proto_rawDescData []byte
)

func file_internal_testprotos_lazy_lazy_extension_normalized_wire_test_proto_rawDescGZIP() []byte {
	file_internal_testprotos_lazy_lazy_extension_normalized_wire_test_proto_rawDescOnce.Do(func() {
		file_internal_testprotos_lazy_lazy_extension_normalized_wire_test_proto_rawDescData = protoimpl.X.CompressGZIP(unsafe.Slice(unsafe.StringData(file_internal_testprotos_lazy_lazy_extension_normalized_wire_test_proto_rawDesc), len(file_internal_testprotos_lazy_lazy_extension_normalized_wire_test_proto_rawDesc)))
	})
	return file_internal_testprotos_lazy_lazy_extension_normalized_wire_test_proto_rawDescData
}

var file_internal_testprotos_lazy_lazy_extension_normalized_wire_test_proto_msgTypes = make([]protoimpl.MessageInfo, 3)
var file_internal_testprotos_lazy_lazy_extension_normalized_wire_test_proto_goTypes = []any{
	(*Sub)(nil), // 0: lazy_extension_normalized_wire_test.Sub
	(*Top)(nil), // 1: lazy_extension_normalized_wire_test.Top
	(*Ext)(nil), // 2: lazy_extension_normalized_wire_test.Ext
}
var file_internal_testprotos_lazy_lazy_extension_normalized_wire_test_proto_depIdxs = []int32{
	0, // 0: lazy_extension_normalized_wire_test.Sub.grandchild:type_name -> lazy_extension_normalized_wire_test.Sub
	0, // 1: lazy_extension_normalized_wire_test.Top.child:type_name -> lazy_extension_normalized_wire_test.Sub
	0, // 2: lazy_extension_normalized_wire_test.Ext.b:extendee -> lazy_extension_normalized_wire_test.Sub
	2, // 3: lazy_extension_normalized_wire_test.Ext.b:type_name -> lazy_extension_normalized_wire_test.Ext
	4, // [4:4] is the sub-list for method output_type
	4, // [4:4] is the sub-list for method input_type
	3, // [3:4] is the sub-list for extension type_name
	2, // [2:3] is the sub-list for extension extendee
	0, // [0:2] is the sub-list for field type_name
}

func init() { file_internal_testprotos_lazy_lazy_extension_normalized_wire_test_proto_init() }
func file_internal_testprotos_lazy_lazy_extension_normalized_wire_test_proto_init() {
	if File_internal_testprotos_lazy_lazy_extension_normalized_wire_test_proto != nil {
		return
	}
	type x struct{}
	out := protoimpl.TypeBuilder{
		File: protoimpl.DescBuilder{
			GoPackagePath: reflect.TypeOf(x{}).PkgPath(),
			RawDescriptor: unsafe.Slice(unsafe.StringData(file_internal_testprotos_lazy_lazy_extension_normalized_wire_test_proto_rawDesc), len(file_internal_testprotos_lazy_lazy_extension_normalized_wire_test_proto_rawDesc)),
			NumEnums:      0,
			NumMessages:   3,
			NumExtensions: 1,
			NumServices:   0,
		},
		GoTypes:           file_internal_testprotos_lazy_lazy_extension_normalized_wire_test_proto_goTypes,
		DependencyIndexes: file_internal_testprotos_lazy_lazy_extension_normalized_wire_test_proto_depIdxs,
		MessageInfos:      file_internal_testprotos_lazy_lazy_extension_normalized_wire_test_proto_msgTypes,
		ExtensionInfos:    file_internal_testprotos_lazy_lazy_extension_normalized_wire_test_proto_extTypes,
	}.Build()
	File_internal_testprotos_lazy_lazy_extension_normalized_wire_test_proto = out.File
	file_internal_testprotos_lazy_lazy_extension_normalized_wire_test_proto_goTypes = nil
	file_internal_testprotos_lazy_lazy_extension_normalized_wire_test_proto_depIdxs = nil
}
